@@ -1,3 +1,9 @@
+
+"""This module provides the class DB, main class of silly_db.
+
+"""
+
+
 import os
 import sqlite3
 from silly_db.helpers import (
@@ -10,59 +16,12 @@ from silly_db.exceptions import (
     MIGRATE_ALL_ERROR,
 )
 
-
-class Selection:
-    """Object returned by the DB.select method, it contains the result
-    of the query in a convenient form allowing easy manipulations.
-    - self.items is a list of SelectionItems."""
-    def __init__(self, *args):
-        self.items = [*args]
-
-    def __str__(self) -> str:
-        display = "<Selection["
-        for elem in self.items:
-            display += str(elem)+", "
-        display += "]>"
-        return display
-
-    def __iter__(self):
-        return iter(self.items)
-
-    def __add__(self, other):
-        array = list(set([*self.items, *other.items]))
-        return Selection(*array)
-
-    def jsonify(self):
-        """Returns an array of SelectionItems turned into dicts"""
-        array = []
-        for item in self.items:
-            array.append(dict(item))
-        return array
-
-    def exists(self) -> bool:
-        if len(self.items) > 0:
-            return True
-        return False
-
-    def order_by(self, key=None, reverse=False):
-        return sorted(
-            self.items, key=lambda x: getattr(x, key), reverse=reverse)
-
-
-class SelectionItem:
-    """db.select() will build SelectionItems with some given attributes
-    and create a Selection object, filled with SelectionItems"""
-    def __str__(self) -> str:
-        return str(dict(self))
-
-    def __repr__(self) -> str:
-        return str(self)
-
-    def __iter__(self):
-        """dict(SelectionItem) converts the
-        SelectionItem into a dict"""
-        for attr in vars(self):
-            yield attr, getattr(self, attr)
+from silly_db.selections import (
+    Selection,
+    SelectionItem,
+    Model,
+    VirtualModel,
+)
 
 
 class DB:
@@ -119,6 +78,11 @@ class DB:
                 )
         return uniques
 
+    def model(self, table):
+        """Takes a table name as parameter, returns the table as a Model"""
+        new_model = Model(self, table)
+        return new_model
+
     def execute(self, command):
         """'Begin transaction' and 'commit' are automatically added
         to the command, so don't use this key words."""
@@ -170,18 +134,22 @@ class DB:
             file for file in os.listdir(apply_dir)
             if file.lower().endswith(".sql")
             ]
+        files.sort()
         for file in files:
             self.migrate(os.path.abspath(os.path.join(apply_dir, file)))
 
     def export(
-        self, structure_file="structure.sql", data_file="data.sql",
+        self,
+        structure_file="00_structure.sql_bkp",
+        data_file="01_data.sql_bkp",
         action="both"  # both / structure / data
             ):
         """By default export both data and structure with default file names"""
         structure = ""
         data = "BEGIN TRANSACTION;\n"
         for line in self.connection.iterdump():
-            if "sqlite_sequence" not in line:
+            if "sqlite_sequence" not in line and \
+                    "_migrations_applied" not in line:
                 if line.startswith("INSERT"):
                     data += line+"\n"
                 else:
@@ -198,10 +166,11 @@ class DB:
         """Exports both structure and data to a single file,
          into a sql format."""
         if file is None:
-            file = "backup_all_in_one.sql"
+            file = "backup_all_in_one.sql_bkp"
         with open(file, 'w') as f:
             for line in self.connection.iterdump():
-                if "sqlite_sequence" not in line:
+                if "sqlite_sequence" not in line and \
+                        "_migrations_applied" not in line:
                     f.write(f"{line}\n")
 
     def export_data(self, file=None):
@@ -216,20 +185,23 @@ class DB:
         """Exports only the structure of the database to a given file,
         into a sql format."""
         if file is None:
-            file = "structure.sql"
+            file = "00_structure.sql_bkp"
         self.cursor.execute("SELECT sql FROM sqlite_master;")
         with open(file, 'w') as f:
             f.write("BEGIN TRANSACTION;\n")
             for line in self.cursor.fetchall():
-                if "sqlite_sequence" not in line[0]:
+                if "sqlite_sequence" not in line[0] and \
+                        "_migrations_applied" not in line[0]:
                     f.write(f"{line[0]};\n")
             f.write("COMMIT;")
 
-    def select(self, command: str) -> Selection:
-        """Query tool, the parameter is a purely SQL query, but without
-        the word SELECT at the beginig (as it's already the method name)
-        """
-        self.cursor.execute("SELECT " + command)
+    def view(self, *args):
+        """returns a VirtualModel object"""
+        return VirtualModel(self, *args)
+
+    def query(self, command: str) -> Selection:
+        """command is a SQL query, returns a Selection object"""
+        self.cursor.execute(command)
         headers = self._get_headers(self.cursor.description)
         results = self.cursor.fetchall()
         answers = []
@@ -239,9 +211,14 @@ class DB:
             answers.append(elem)
         for answer in answers:
             dico = dict(answer.items())
-            response = SelectionItem()
-            for key in dico:
-                setattr(response, key, dico[key])
+            response = SelectionItem(dico)
             responses.append(response)
-        query_set = Selection(*responses)
-        return query_set
+        selection = Selection(*responses)
+        return selection
+
+    def select(self, command: str) -> Selection:
+        """Query tool, the parameter is a purely SQL query, but without
+        the word SELECT at the beginig (as it's already the method name)
+        """
+        command = "SELECT " + command
+        return self.query(command)
